# drf-base64-filename

**drf-base64-filename** provides Serializer fields for using base64-encoded files with file names.

## Setup

- Install `drf-base64-filename` to your Python environment

  ```shell
  pip install drf-base64-filename
  ```




## Contributing

As an open source project, we welcome contributions.
The code lives on [GitHub](https://github.com/LeeHanYeong/drf-base64-filename)

 